@@ -1,5 +1,5 @@
 /*  Rational - Rational number class with overflow detection
-    Copyright (C) 2012-2018 Antonio Diaz Diaz.
+    Copyright (C) 2012-2019 Antonio Diaz Diaz.
 
     This program is free software. Redistribution and use in source and
     binary forms, with or without modification, are permitted provided
@@ -37,17 +37,38 @@
 
 namespace {
 
-const char * const Program_name = "Rational";
 const char * const program_name = "rational";
-const char * const program_year = "2018";
+const char * const program_year = "2019";
 const char * invocation_name = 0;
 
 
 void show_help()
   {
-  std::printf( "%s - Rational number class with overflow detection.\n", Program_name );
-  std::printf( "See the source file 'main.cc' to learn how to use %s in\n", Program_name );
-  std::printf( "your own programs.\n"
+  std::printf( "Rational is a C++ class implementing rational numbers of limited size with\n"
+               "overflow detection. Both numerator and denominator are of type 'int'.\n"
+               "\nRational allows you to perform exact calculations and verify at any time if\n"
+               "overflow has occurred. Rational does not throw exceptions.\n"
+               "\nIn case of domain error or overflow, denominator is set to 0 and numerator\n"
+               "is set to >0, <0 or 0, meaning +INF, -INF and NAN respectively. This error\n"
+               "condition can be tested with the 'error' function, and can only be cleared\n"
+               "assigning a new value to the Rational.\n"
+               "\nWhile in error state, arithmetic operators become no ops and relational\n"
+               "operators return false, except '!=', which returns true. This is done to\n"
+               "preserve the error condition which triggered the error, and because the\n"
+               "error value is considered to be out of domain and therefore is different\n"
+               "from any valid value, but not necessarily larger or smaller.\n"
+               "\nThe 'parse' function can be used to obtain values exactly representable by\n"
+               "small fractions like '0.1', '1/3' or '355/113' from the command line.\n"
+               "\nThe 'to_decimal' function prints values in decimal point form (123.456),\n"
+               "while the 'to_fraction' function prints values in fraction form (123/456).\n"
+               "Both functions print '+INF', '-INF' or 'NAN' to signal an error condition.\n"
+               "\nValues are kept normalized (gcd(numerator,denominator) == 1, and the\n"
+               "denominator is positive).\n"
+               "Range extends from INT_MAX to -INT_MAX.\n"
+               "Maximum resolution is 1 / INT_MAX.\n"
+               "\nTo use the Rational class in your own programs simply copy the files\n"
+               "'rational.h' and 'rational.cc' in your source tree. See also the file\n"
+               "'main.cc' for an example of use.\n"
                "\nUsage: %s [options] [arguments]\n", invocation_name );
   std::printf( "\nOptions:\n"
                "  -h, --help                   display this help and exit\n"
@@ -77,11 +98,9 @@ void show_error( const char * const msg, const int errcode = 0,
                  const bool help = false )
   {
   if( msg && msg[0] )
-    {
-    std::fprintf( stderr, "%s: %s", program_name, msg );
-    if( errcode > 0 ) std::fprintf( stderr, ": %s", std::strerror( errcode ) );
-    std::fputc( '\n', stderr );
-    }
+    std::fprintf( stderr, "%s: %s%s%s\n", program_name, msg,
+                  ( errcode > 0 ) ? ": " : "",
+                  ( errcode > 0 ) ? std::strerror( errcode ) : "" );
   if( help )
     std::fprintf( stderr, "Try '%s --help' for more information.\n",
                   invocation_name );
